Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Schroot ¶
type Schroot struct {
// contains filtered or unexported fields
}
Schroot object encapsulation. Contains lightweight amounts of state, so it's advised that you pass a pointer to this around.
func NewSchroot ¶
Create a new schroot based on the chroot name. To get an idea of what chroots exist on the system, run `schroot -l --all-chroots`.
func (*Schroot) Command ¶
Create a os/exec.Cmd to run the command inside the schroot chroot. Keep in mind that we're not currently smart enough to deal with things like the enviorn in a native way, so don't get too cute.
func (*Schroot) End ¶
Close the schroot session, killing the open session from schroot. To see how many you've left open because you forgot to call this method, run `schroot -l --all-sessions`. To close them, run `schroot -e -c session:xxxx` (where session:xxxx is the name, as seen in schroot -l output)
It's advised that you `defer` this whenever creating a new schroot.